==> api-vertx-client-0.7.20.6.1-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/NetworkRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.NetworkTypeDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2020-01-01T18:24:23.294947664-03:00[America/Argentina/Buenos_Aires]")
public class NetworkRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.NetworkRoutesApi delegate;

	public NetworkRoutesApi(io.nem.sdk.openapi.vertx.api.NetworkRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.NetworkRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get the current network type of the chain
     * Returns the current network type.
     * @param resultHandler Asynchronous result handler
     */
    public void getNetworkType(Handler<AsyncResult<NetworkTypeDTO>> resultHandler) {
        delegate.getNetworkType(resultHandler);
    }

    /**
     * Get the current network type of the chain
     * Returns the current network type.
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NetworkTypeDTO> rxGetNetworkType() {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNetworkType(fut);
        }));
    }

    public static NetworkRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.NetworkRoutesApi arg) {
        return arg != null ? new NetworkRoutesApi(arg) : null;
    }
}

==> api-vertx-client-0.7.21-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/NetworkRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.NetworkTypeDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2019-11-23T10:26:45.594287+01:00[Europe/Madrid]")
public class NetworkRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.NetworkRoutesApi delegate;

	public NetworkRoutesApi(io.nem.sdk.openapi.vertx.api.NetworkRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.NetworkRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get the current network type of the chain
     * Returns the current network type.
     * @param resultHandler Asynchronous result handler
     */
    public void getNetworkType(Handler<AsyncResult<NetworkTypeDTO>> resultHandler) {
        delegate.getNetworkType(resultHandler);
    }

    /**
     * Get the current network type of the chain
     * Returns the current network type.
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NetworkTypeDTO> rxGetNetworkType() {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNetworkType(fut);
        }));
    }

    public static NetworkRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.NetworkRoutesApi arg) {
        return arg != null ? new NetworkRoutesApi(arg) : null;
    }
}
